<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'pet_business_pro_contact_section', array(
	'title'             => esc_html__( 'Contact','pet-business-pro' ),
	'description'       => esc_html__( 'Contact Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_contact_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

if ( class_exists( 'WPCF7' ) ) {
	$description = sprintf( __( 'You can manage the Contact Form 7 shortcodes from %1$s here %2$s.', 'pet-business-pro' ), '<a href="' .  esc_url( admin_url('admin.php?page=wpcf7' ) ) . '" target="_blank">', '</a>' );
} else {
	$description = sprintf( __( 'We recommend you to install Contact Form 7 plugin from %1$s here %2$s</a> for shortcodes.', 'pet-business-pro' ), '<a href="' .  esc_url( admin_url('themes.php?page=tgmpa-install-plugins' ) ) . '" target="_blank">', '</a>' );
}

// contact image setting and control.
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_shortcode]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[contact_shortcode]',
		array(
		'label'       		=> esc_html__( 'Contact shortcode', 'pet-business-pro' ),
		'description'		=> $description,
		'section'     		=> 'pet_business_pro_contact_section',
		'active_callback'	=> 'pet_business_pro_is_contact_section_enable',
) );

// Contact content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_content_type]', array(
	'default'          	=> $options['contact_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[contact_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_contact_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_contact_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'pet-business-pro' ),
		'post' 		=> esc_html__( 'Post', 'pet-business-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'pet-business-pro' ),
	),
) );

// contact pages drop down chooser control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_content_page]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_page',
) );

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[contact_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_contact_section',
	'choices'			=> pet_business_pro_page_choices(),
	'active_callback'	=> 'pet_business_pro_is_contact_section_content_page_enable',
) ) );

// contact posts drop down chooser control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_content_post]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_page',
) );

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[contact_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_contact_section',
	'choices'			=> pet_business_pro_post_choices(),
	'active_callback'	=> 'pet_business_pro_is_contact_section_content_post_enable',
) ) );

// contact title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_contact_section',
	'active_callback' 	=> 'pet_business_pro_is_contact_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[contact_title]', array(
		'selector'            => '#contact-us .entry-header h2.entry-title',
		'settings'            => 'pet_business_pro_theme_options[contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_contact_title_partial',
    ) );
}

// contact description setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['contact_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[contact_description]', array(
	'label'           	=> esc_html__( 'Description', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_contact_section',
	'active_callback' 	=> 'pet_business_pro_is_contact_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[contact_description]', array(
		'selector'            => '#contact-us .entry-content p',
		'settings'            => 'pet_business_pro_theme_options[contact_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_contact_description_partial',
    ) );
}

// contact image control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[contact_image]', array(
	'label'             => esc_html__( 'Image', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_contact_section',
	'active_callback'   => 'pet_business_pro_is_contact_section_content_custom_enable',
) ) );

for ( $i=1; $i < 3; $i++ ) { 
	// contact custom date
	$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_text_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[contact_text_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Address title %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_contact_section',
		'active_callback'	=> 'pet_business_pro_is_contact_section_enable',
	) );

	// contact custom button
	$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[contact_value_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Value %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_contact_section',
		'active_callback'	=> 'pet_business_pro_is_contact_section_enable',
	) );

	// service note control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_textarea_field',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Icon_Picker( $wp_customize, 'pet_business_pro_theme_options[contact_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_contact_section',
		'active_callback'	=> 'pet_business_pro_is_contact_section_enable',
		'type'				=> 'textarea',
	) ) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[contact_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[contact_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_contact_section',
		'active_callback'	=> 'pet_business_pro_is_contact_section_enable',
		'type'				=> 'custom-html',
	) ) );
}