<?php
/**
 * Pricing Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Pricing section
$wp_customize->add_section( 'pet_business_pro_pricing_section', array(
	'title'             => esc_html__( 'Pricing','pet-business-pro' ),
	'description'       => esc_html__( 'Pricing Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Pricing content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_section_enable]', array(
	'default'			=> 	$options['pricing_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[pricing_section_enable]', array(
	'label'             => esc_html__( 'Pricing Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_pricing_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// pricing title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['pricing_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_pricing_section',
	'active_callback' 	=> 'pet_business_pro_is_pricing_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[pricing_title]', array(
		'selector'            => '#pricing-table h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[pricing_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_pricing_title_partial',
    ) );
}

// pricing sub title
$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_sub_title]', array(
	'default'          	=> $options['pricing_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_sub_title]', array(
	'label'             => esc_html__( 'Sub title', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_pricing_section',
	'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[pricing_sub_title]', array(
		'selector'            => '#pricing-table .section-subtitle',
		'settings'            => 'pet_business_pro_theme_options[pricing_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_pricing_sub_title_partial',
    ) );
}

// pricing number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[pricing_image]', array(
	'label'             => esc_html__( 'Image', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_pricing_section',
	'active_callback'   => 'pet_business_pro_is_pricing_section_enable',
) ) );

// pricing number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_count]', array(
	'default'          	=> $options['pricing_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_count]', array(
	'label'             => esc_html__( 'Number of Product', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 3. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_pricing_section',
	'active_callback'   => 'pet_business_pro_is_pricing_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 3,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['pricing_count']; $i++ ) :
	// pricing title
	$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
	) );

	// pricing price
	$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_price_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_price_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Price %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
	) );

	// contact email setting and control
	$wp_customize->add_setting( 'pet_business_pro_theme_options[price_list_' . $i. ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Multi_Input_Custom_Control( $wp_customize, 'pet_business_pro_theme_options[price_list_' . $i. ']', array(
		'label'             => esc_html__( 'List text', 'pet-business-pro' ),
		'button_text'       => esc_html__( 'Add list.', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback' 	=> 'pet_business_pro_is_pricing_section_enable',
	) ) );

	// pricing btn
	$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_btn_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_btn_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Button %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
	) );

	// pricing btn link
	$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_btn_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[pricing_btn_url_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Link %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
		'type'				=> 'url'
	) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[pricing_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[pricing_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_pricing_section',
		'active_callback'	=> 'pet_business_pro_is_pricing_section_enable',
		'type'				=> 'custom-html',
	) ) );

endfor;